@@ -20,7 +20,9 @@ def __default_dot_style_func__(mp):
     return props
 
 # TODO: Use graphviz apis instead of constructing strings
-def __get_graphviz_data__(vertex_map, edges_maps, node_props, edge_props, vertex_id_col, edge_src_col, edge_dest_col, vertex_display_id_col, style_func, max_len):
+def __get_graphviz_data__(vertex_map, edges_maps, node_props, edge_props, vertex_id_col, edge_src_col, edge_dest_col, vertex_display_id_col, style_func, max_len,
+    display_vertex_keys, display_edge_keys):
+
     # check for custom display
     if (style_func is None):
         style_func = __default_dot_style_func__
@@ -54,7 +56,13 @@ def __get_graphviz_data__(vertex_map, edges_maps, node_props, edge_props, vertex
             for k1 in node_props:
                 # get the value and generate key-value string
                 v1 = str(mp[k1]) if (k1 in mp.keys()) else ""
-                kv_str = "[{} = {}]".format(k1, v1)
+
+                # decide whether to display keys
+                kv_str = None
+                if (display_vertex_keys is None or k1 in display_vertex_keys):
+                    kv_str = "[{} = {}]".format(k1, v1)
+                else:
+                    kv_str = "[{}]".format(v1)
 
                 # truncate the value if it exceeds a specific threshold
                 if (max_len is not None and len(kv_str) > max_len):
@@ -97,8 +105,14 @@ def __get_graphviz_data__(vertex_map, edges_maps, node_props, edge_props, vertex
             for k1 in edge_props:
                 # get the value and generate key-value string
                 v1 = str(mp[k1]) if (k1 in mp.keys()) else ""
+
                 if (v1 != ""):
-                    kv_str = "[{}]".format(v1)
+                    # decide whether to display keys
+                    kv_str = None
+                    if (display_edge_keys is None or k1 in display_edge_keys):
+                        kv_str = "[{} = {}]".format(k1, v1)
+                    else:
+                        kv_str = "[{}]".format(v1)
 
                     # truncate the value if it exceeds a specific threshold
                     if (max_len is not None and len(kv_str) > max_len):
@@ -122,13 +136,13 @@ def __get_graphviz_data__(vertex_map, edges_maps, node_props, edge_props, vertex
     digraph_str = "\n".join(digraph_arr)
 
     # debug
-    utils.debug(digraph_str)
+    utils.trace(digraph_str[0:100] + "...")
 
     # return
     return digraph_str
 
 def get_graphviz_data(vtsv, etsv, vertex_id_col, src_edge_col, dest_edge_col, vertex_display_id_col = None, node_props = None, edge_props = None, style_func = None,
-    max_len = None, create_missing_vertices = False):
+    max_len = None, create_missing_vertices = False, display_vertex_keys = None, display_edge_keys = None):
 
     # default for vertex display
     if (vertex_display_id_col is None):
@@ -146,8 +160,8 @@ def get_graphviz_data(vtsv, etsv, vertex_id_col, src_edge_col, dest_edge_col, ve
         vtsv \
             .group_count(vertex_id_col, "group") \
             .gt_int("group:count", 1) \
-            .sort(vertex_id_col) \
-            .show(max_col_width = 1000)
+            .reverse_numerical_sort("group:count") \
+            .show(10, title = "Top 10 non unique vertex ids", max_col_width = 1000)
 
     # ideally all edge ids must be present in the vertices. fallback to create missing vertices
     missing_edge_ids = edge_ids.difference(vertex_ids)
@@ -159,7 +173,7 @@ def get_graphviz_data(vtsv, etsv, vertex_id_col, src_edge_col, dest_edge_col, ve
 
     # display warning for vertices that dont have edges
     if (len(no_edge_vertex_ids) > 0):
-        utils.warn("There are vertices that dont have edges: {}".format(no_edge_vertex_ids))
+        utils.warn("There are vertices that dont have edges: {}: {}".format(len(no_edge_vertex_ids), str(no_edge_vertex_ids)[0:100] + "..."))
 
     # check if need to create proxy vertices for which there are edges but no vertex properties
     if (len(missing_edge_ids) > 0):
@@ -183,13 +197,15 @@ def get_graphviz_data(vtsv, etsv, vertex_id_col, src_edge_col, dest_edge_col, ve
         edges_maps[(mp[src_edge_col], mp[dest_edge_col])] = mp
 
     # get the graphviz output
-    return __get_graphviz_data__(vertex_map, edges_maps, node_props, edge_props, vertex_id_col, src_edge_col, dest_edge_col, vertex_display_id_col, style_func, max_len)
+    return __get_graphviz_data__(vertex_map, edges_maps, node_props, edge_props, vertex_id_col, src_edge_col, dest_edge_col, vertex_display_id_col, style_func, max_len,
+        display_vertex_keys, display_edge_keys)
 
 def plot_graph(vtsv, etsv, vertex_id_col, src_edge_col, dest_edge_col, vertex_display_id_col = None, node_props = None, edge_props = None, style_func = None,
-    max_len = None, create_missing_vertices = False):
+    max_len = None, create_missing_vertices = False, display_vertex_keys = None, display_edge_keys = None):
 
     digraph_str = get_graphviz_data(vtsv, etsv, vertex_id_col, src_edge_col, dest_edge_col, vertex_display_id_col = vertex_display_id_col, node_props = node_props,
-        edge_props = edge_props, style_func = style_func, max_len = max_len, create_missing_vertices = create_missing_vertices)
+        edge_props = edge_props, style_func = style_func, max_len = max_len, create_missing_vertices = create_missing_vertices, display_vertex_keys = display_vertex_keys,
+        display_edge_keys = display_edge_keys)
 
     # return
     return graphviz.Source(digraph_str)
